'use strict';

var _ = require('.');

var _2 = _interopRequireDefault(_);

var _path = require('path');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Skypager Document Collection', function () {
  it('defines scopes', function () {
    var docsCollection = new _2.default({
      base: (0, _path.join)(process.cwd(), 'test', 'fixtures')
    });

    docsCollection.scope('testcases', /^testcases/);

    docsCollection.scope('testcases').should.be.an('object');
  });

  it('has an instance id', function () {
    var docsCollection = new _2.default({
      type: 'documents',
      base: (0, _path.join)(process.cwd(), 'test', 'fixtures', 'testcases')
    });

    docsCollection.should.have.property('instanceId');
    docsCollection.should.have.property('pathId');
  });

  it('has a type', function () {
    var docsCollection = new _2.default({
      type: 'documents',
      base: (0, _path.join)(process.cwd(), 'test', 'fixtures', 'testcases')
    });

    docsCollection.should.have.property('type', 'document');
  });

  it('has a path router', function () {
    var docsCollection = new _2.default({
      type: 'documents',
      base: (0, _path.join)(process.cwd(), 'test', 'fixtures', 'testcases')
    });

    docsCollection.should.have.property('router');
  });

  it('has an importer with some files', function () {
    var docsCollection = new _2.default({
      type: 'documents',
      base: (0, _path.join)(process.cwd(), 'test', 'fixtures', 'testcases')
    });

    docsCollection.should.have.property('importer').that.is.an('object');
    docsCollection.should.have.property('files').that.is.an('array');
  });

  it('loads files', function (done) {
    var docsCollection = new _2.default({
      type: 'documents',
      base: (0, _path.join)(process.cwd(), 'test', 'fixtures', 'testcases')
    });

    docsCollection.ready.then(function (importer) {
      importer.files.should.not.be.empty;
      done();
    });
  });

  it('specifies patterns based on the type of collection', function () {
    var docsCollection = new _2.default({
      type: 'documents',
      base: (0, _path.join)(process.cwd(), 'test', 'fixtures', 'testcases')
    });

    docsCollection.patterns.should.include('**/*.md');
  });
});